#
# spec file for package mysql-workbench
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define edition community
Name:           mysql-workbench
Version:        8.0.15
Release:        bp153.1.28
Summary:        A MySQL visual database modeling, administration and querying tool
License:        GPL-2.0-only AND GPL-2.0-or-later
Group:          Productivity/Databases/Clients
Url:            http://wb.mysql.com
Source:         http://dev.mysql.com/get/Downloads/MySQLGUITools/%{name}-%{edition}-%{version}-src.tar.gz
Source1:        openSUSE_Vendor_Package.xml
Source2:        %{name}-%{edition}-%{version}-prebuilt_parsers.tar.gz
Source99:       %{name}.rpmlintrc
#Patches
Patch0:         patch-desktop-categories.patch
# Remove check for update in help
Patch1:         mysql-workbench-no-check-for-updates.patch
# disabled , system scintila is buil with gtk3
Patch7:         mysql-workbench-unbundle-libscintilla.patch
Patch8:         mysql-workbench-preload-sqlparser.patch
# patch from https://bugs.mysql.com/bug.php?id=84886
Patch11:        git_patch_105207009.patch
Patch13:        mysql-workbench-mariadb.patch
# PATCH-FIX-UPSTREAM guillaume@opensuse.org
Patch14:        fix_aarch64_build.patch
# PATCH-FIX-OPENSUSE allow to both support keyring and start without it
Patch15:        mysql-workbench-keyring-check.patch
# PATCH-FIX-OPENSUSE fix build with MariaDB
Patch16:        mysql-workbench-mariadb-8.0.15.patch
# PATCH-FIX-UPSTREAM fix include path for old JDBC api with new mysql-connector-cpp
Patch17:        mysql-workbench-old-api.patch
# PATCH-FIX-UPSTREAM fix warning interpreted as errors
Patch18:        mysql-workbench-warnings-fix.patch
# PATCH-FIX-OPENSUSE disable parser building (while we have no maven in OBS)
Patch19:        mysql-workbench-prebuilt-parsers.patch
# PATCH-FIX-OPENSUSE fix License.txt location
Patch20:        mysql-workbench-license-location.patch
# PATCH-FIX-UPSTREAM fix HiDPI support
Patch21:        mysql-workbench-hidpi.patch
BuildRequires:  Mesa-devel
BuildRequires:  ant
BuildRequires:  binutils-gold
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  freetds-devel
BuildRequires:  gcc-c++
BuildRequires:  gnome-keyring-devel
BuildRequires:  gtkmm3-devel
BuildRequires:  libantlr4-runtime-devel >= 4.7.2
BuildRequires:  libmysqlclient-devel
BuildRequires:  libmysqlcppconn-devel >= 1.1.8
BuildRequires:  libmysqld-devel > 5.1
BuildRequires:  libscintilla-devel
BuildRequires:  libsigc++2-devel
BuildRequires:  libtool
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  python-paramiko
BuildRequires:  swig
BuildRequires:  tinyxml-devel
BuildRequires:  unixODBC-devel
BuildRequires:  update-desktop-files
BuildRequires:  vsqlite++-devel
BuildRequires:  pkgconfig(cairo) >= 1.5.12
BuildRequires:  pkgconfig(cairomm-1.0)
BuildRequires:  pkgconfig(gdal)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libctemplate)
#BuildRequires:  pkgconfig(libglade-2.0)
#BuildRequires:  pkgconfig(libgnome-2.0)
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libssh) >= 0.8.5
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       libmysqlclient-devel
Requires:       proj
Requires:       python-paramiko
Requires:       python-pexpect
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
Suggests:       gnome-keyring
Suggests:       mysqldump
Conflicts:      mysql-workbench-com-se
Conflicts:      mysql-workbench-oss
Provides:       mysql-administrator = %{version}
Provides:       mysql-gui-tools = %{version}
Provides:       mysql-querybrovser = %{version}
Provides:       mysql-workbench-%{edition}
Obsoletes:      mysql-administrator < %{version}
Obsoletes:      mysql-gui-tools < %{version}
Obsoletes:      mysql-querybrovser < %{version}
ExcludeArch:    %arm %ix86
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif

%description
MySQL Workbench is a modeling tool that allows you to design
and generate MySQL databases graphically. It also has administration
and query development modules where you can manage MySQL server instances
and execute SQL queries.
This is the %{edition} build.

%prep
# Add the -D flag if you don't want to delete the source root on each build
%setup -q -n %{name}-%{edition}-%{version}-src
%setup -q -D -T -b 2 -n %{name}-%{edition}-%{version}-src
%patch0 -p1
%patch1 -p1
%patch7 -p1
%patch8 -p1
%patch11 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1

%build
export CFLAGS="%{optflags}"
%define __builder ninja
# build will fail if -Werror is used on recent complires
sed -i "s|-Werror||g" CMakeLists.txt
# fix building on Leap
truncate -s0 library/base/boost_fix.cpp
%cmake \
  -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now -Wl,-fuse-ld=gold -pie" \
  -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now -Wl,-fuse-ld=gold -pie" \
  -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now -Wl,-fuse-ld=gold -pie" \
  -DMYSQL_CONFIG_PATH=%{_bindir}/mysql_config \
  -DCMAKE_BUILD_TYPE=%{edition} \
  -DREAL_EXECUTABLE_DIR=%{_libdir}/%{name} \
  -DUSE_UNIXODBC=TRUE
%cmake_build

%install
%cmake_install

find %{buildroot}%{_libdir}/%{name} -name \*.a  -exec rm {} \; -print
find %{buildroot} -type f -name "*.la" -delete -print

install -m 0644 "%{SOURCE1}" %{buildroot}%{_datadir}/mysql-workbench/mysql.profiles

mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/%{name}" > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf
chmod 644 %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf

rm -r %{buildroot}%{_datadir}/mime-info

rm -r %{buildroot}%{_datadir}/doc/mysql-workbench

# Check for duplicate files
%fdupes -s %{buildroot}

%post
/sbin/ldconfig
%icon_theme_cache_post
%mime_database_post
%desktop_database_post

%postun
/sbin/ldconfig
%icon_theme_cache_postun
%mime_database_postun
%desktop_database_postun

%files
%defattr(0644, root, root, 0755)
%license License.txt
%doc README.md AUTHORS ChangeLog
%attr(0755,root,root) %{_bindir}/mysql*
%attr(0755,root,root) %{_bindir}/wbcopytables
%attr(0755,root,root) %{_libdir}/%{name}/%{name}-bin
%attr(0755,root,root) %{_libdir}/%{name}/wbcopytables-bin
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib*
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/*
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/*
%dir %{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/mime/packages/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}/*
%attr(0755,root,root) %{_datadir}/%{name}/extras/*.sh
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/%{name}.conf

%changelog
* Sat Feb 23 2019 Mykola Krachkovsky <w01dnick@gmail.com>
- fixed HiDPI: about box now works on HiDPI and got sharper images
  * added mysql-workbench-hidpi.patch
- fixed License.txt location (Help -> Show License Info)
  * added mysql-workbench-license-location.patch
* Sun Feb 17 2019 Mykola Krachkovsky <w01dnick@gmail.com>
- Updated to 8.0.15
  * release notes:
    https://dev.mysql.com/doc/relnotes/workbench/en/news-8-0.html
  * prebuilt parsers regenerated
    mysql-workbench-community-8.0.15-prebuilt_parsers.tar.gz
- fixed upstream
  * removed mysql-workbench-cmake-3.2.patch
  * removed mysql-workbench-gcc6.patch
  * removed mysql-workbench-gdal-use-CPLFree.patch
- system libraries update, no need for relaxing requirement anymore
  * removed mysql-workbench-mysql-version.patch
- MariaDB now supports JSON
  * removed mysql-workbench-no-json.patch
- MariaDB compatablity
  * removed mariadb-no-escape-string-quote.patch, superseded by
  * added mysql-workbench-mariadb-8.0.15.patch
- fixed mysql-connector-cpp includes location
  * added mysql-workbench-old-api.patch
- fixed warning interpreted as errors
  * added mysql-workbench-warnings-fix.patch
- disabled generating of parser files
  (which needs complete antlr4 which needs maven in openSUSE)
  * added mysql-workbench-prebuilt-parsers.patch
- fixed program start in case of keyring absence without
  full keyring disabling
  * added mysql-workbench-keyring-check.patch
* Mon Apr 30 2018 guillaume.gardet@opensuse.org
- Remove abiflags (-m32/64) option for non x86_64 archs
- Add a patch to fix AArch64:
  * fix_aarch64_build.patch
* Mon Feb  5 2018 w01dnick@gmail.com
- add mysql-workbench-mariadb.patch
  to fix compatibility with MariaDB,
  removed not supported options,
  added HAVE_CHARSET_... not used mariadb connector
* Tue Dec 12 2017 w01dnick@gmail.com
- Update to version 6.3.10
  * https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-10.html
- Fixed patch for current version (git_patch_105207009.patch)
* Mon Dec 11 2017 mpluskal@suse.com
- Drop no longer needed mysql-workbench-mysql_options4.patch
* Mon Oct 16 2017 mpluskal@suse.com
- Update license information
* Wed Oct 11 2017 sbrabec@suse.com
- Drop obsolete mime-info (boo#1062631).
* Wed May 31 2017 mpluskal@suse.com
- Update to version 6.3.9:
  * https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-8.html
  * https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-9.html
  * resolves CVE-2017-3469 (boo#1035195)
- Add patches:
  * mariadb-no-escape-string-quote.patch
  * git_patch_105207009.patch
  * mysql-workbench-gdal-use-CPLFree.patch
- Stop building on 32-bit architectures
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Nov 12 2016 mpluskal@suse.com
- Fix building with latest gcc6
  * mysql-workbench-gcc6.patch
* Sun Oct  9 2016 mpluskal@suse.com
- Use ninja and gold linker to speedup building
* Fri Aug  5 2016 mimi.vx@gmail.com
- fix build on Leap:42.2 -- force -std=c++11
- add _constraints file
* Thu Jul 21 2016 w01dnick@gmail.com
- added mysql-workbench-preload-sqlparser.patch to preload
  mysql-workbench/libsqlparser.so which is needed by
  mysql-workbench/modules/db.mysql.sqlparser.grt.so
  to open connection but isn't loaded
* Wed Jul 20 2016 mimi.vx@gmail.com
- disable mysql-workbench-unbundle-libscintilla.patch , openSUSE
    scintilla is build with GTK3, but mysql-workbench with GTK2
* Tue Jul 12 2016 tchvatal@suse.com
- Reduce some pointless comments
- Use normal paralel build
- Switch to pkgconfig style deps where possible
- Unbundle scintilla:
  * mysql-workbench-unbundle-libscintilla.patch
- Use %%cmake macros fully
* Mon Jul 11 2016 mimi.vx@gmail.com
- update to version 6.3.7
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-7.html
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-6.html
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-5.html
- dropped patches:
  mysql-workbench-community-6.3.3-src-mysql_options4.patch
- refreshed patches:
  mysql-workbench-cmake-3.2.patch
  mysql-workbench-no-check-for-updates.patch
  patch-desktop-categories.patch
- added patches:
    mysql-workbench-mysql-version.patch - relax mysql version req.
    mysql-workbench-mysql_options4.patch - disable options4, doesn't work as
    supposed with MariaDB
    mysql-workbench-no-json.patch - disable JSON support, no antlr3 in openSUSE
- removed support for unsupported distributions
- openSUSE_(Vendor_Package).xml renamed to openSUSE_Vendor_Package.xml
* Tue Jun 23 2015 aj@ajaissle.de
- update to version 6.3.4
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-4.html
- update to version 6.3.3
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-3-3.html
- update to version 6.2.5
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-2-5.html
- update to version 6.2.4
  https://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-2-4.html
- Rebased Patch:
  * mysql-workbench-mysql_options4.patch as
    mysql-workbench-community-6.3.3-src-mysql_options4.patch
  * mysql-workbench-cmake-3.2.patch
- Removed Patches:
  - mysql-workbench-ctemplate.patch (fixed in 6.2.5)
  - mysql-workbench-glib.patch (fixed in 6.3.3)
- Requires antlr-java = 3.4 for build. As we have no package for
  that, yet, we use the bundled antlr.
* Fri Jun  5 2015 wbauer@tmo.at
- added mysql-workbench-glib.patch: fix empty grid result
  (http://bugs.mysql.com/74147, boo#904767)
* Fri Mar 27 2015 sfalken@opensuse.org
- Patched to work with CMake >=3.2, as X11 is no longer magically
  implied as a linked library
- Added:
  + mysql-workbench-cmake-3.2.patch
* Thu Oct  2 2014 ecsos@schirra.net
- update to version 6.2.3
  http://dev.mysql.com/doc/relnotes/workbench/en/changes-6-2.html
- use unixodbc instead of libiodbc
  - change DUSE_UNIXODBC from false to true,
  - remove BuildRequires libiodbc-devel
- insert libgdal-devel and postgresql-devel
* Thu Sep 11 2014 michal.hrusecky@opensuse.org
- not using %%cmake macro for now, causes too much troubles,
  needs further investigation
* Sun Sep  7 2014 michal.hrusecky@opensuse.org
- fix build by ommiting -Wl,--no-undefined
- adding -Wl,-z,relro
* Wed Jul 16 2014 ecsos@schirra.net
- insert libmysqlclient-devel for missing link
  (could not login mysqlserver)
- change lib in libdir in DLIB_INSTALL_DIR
  (workbench dont#'t start)
- comment out LDFLAGS
  (could only start as root, missing libgcc_s1)
* Sun Jul  6 2014 bruno@ioda-net.ch
- update to version 6.1.7
- Fix compilation issues on several distribution
- Added patch fixing build error inexistant mysql_option4
  mysql-workbench-mysql_options4.patch
- Added patch to remove help check for upgrade
  mysql-workbench-no-check-for-updates.patch
- Added patch to fix deprecate call ctemplate
  mysql-workbench-ctemplate.patch
  upstream bug http://bugs.mysql.com/72585
* Wed Apr 23 2014 ecsos@schirra.net
- update to version 6.1.4
* Thu Feb  6 2014 ecsos@schirra.net
- update to 6.0.9
- insert Requires: libmysqlclient-devel because of absence symlink
  of libmysqlclient_r.so
* Mon Oct  7 2013 mhrusecky@suse.cz
- updated to version 6.0.7
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-0-7.html
- further cleanup of spec file
* Tue Aug 20 2013 bruno@ioda-net.ch
- update to version 6.0.6
  * see http://www.mysql.com/products/workbench/
- packaging : cleaning old options, wb use cmake now
  removed no more used patches
  mysql-workbench-gpl-5.2.44-ctemplate-fix.patch
  mysql-workbench-gpl-5.2.44-avoid-version.patch
  mysql-workbench-5.2.47-system-cppconn.patch
* Wed Aug  7 2013 gankov@opensuse.org
- Add symbolic link to libmysqlclient_r
* Thu Jun  6 2013 mhrusecky@suse.com
- ugly hack around loading cppconnector manually
* Tue Jun  4 2013 mhrusecky@suse.com
- Fixed build against Factory (gtkmm/*.h -> gtkmm.h)
- Use system c++-connector:
  mysql-workbench-5.2.47-system-cppconn.patch
* Tue Mar 12 2013 speilicke@suse.com
- Fix invalid changes entry
* Wed Mar  6 2013 hpj@urpla.net
- update to version 5.2.47
  see
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-5-2-47.html
* Wed Mar  6 2013 opensuse@sukimashita.com
- update to version 5.2.46
  see
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-5-2-46.html
* Wed Jan 23 2013 gankov@opensuse.org
- update to version 5.2.45
  see
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-5-2-45.html
* Sat Nov 24 2012 gankov@opensuse.org
- update to version 5.2.44
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-44.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-43.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-42.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-41.html
- Add build dependency on libiodbc
- rebase patches
- Don't blindly remove libs from %%{_libdir}/%%{name}/
  Some of them is runtime dependencies
* Thu Nov 15 2012 hpj@urpla.net
- build and static link included antlr3
* Wed Nov 14 2012 hpj@urpla.net
- update to version 5.2.44
- rebase patches
* Tue Sep 18 2012 idonmez@suse.com
- Add build dependency on xxf86vm to fix the build
* Sun Jun 17 2012 gankov@opensuse.org
- update to version 5.2.40
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-40.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-39.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-38.html
- add mime type support
- use fdups
- rebase patches
* Mon Mar 19 2012 bruno@ioda-net.ch
- Fix build by adding libuuid-devel
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Jan 30 2012 mhrusecky@suse.cz
- update to version 5.2.37
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-37.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-36.html
- fixed glib headers to include glib.h only
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Sep 30 2011 mhrusecky@suse.cz
- update to version 5.2.35
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-35.html
* Tue Sep 13 2011 mhrusecky@suse.cz
- fixed openSUSE configuration
* Sun Sep 11 2011 mhrusecky@suse.cz
- readded patches
- enabled command line utilities
* Mon Sep  5 2011 bruno@ioda-net.ch
- Upgraded to version 5.2.34
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-34.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-33.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-32.html
- removed all patches
* Thu Dec  9 2010 mhrusecky@suse.cz
- update to the version 5.2.31
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-31.html
* Tue Nov 30 2010 mhrusecky@suse.cz
- added provides and obsoletes
* Mon Nov 29 2010 mhrusecky@suse.cz
- cleanup before submitting
* Mon Nov 22 2010 mhrusecky@suse.cz
- update to the version 5.2.30
  - recent changes
  http://dev.mysql.com/doc/workbench/en/wb-news-5-2-30.html
  - all changes:
  http://dev.mysql.com/doc/workbench/en/wb-change-history.html
* Tue Jul 27 2010 ro@suse.de
- drop glitz-devel from buildrequires (glitz backend was dropped
  from cairo two years ago)
* Wed May 19 2010 ro@suse.de
- fix build with current compiler
  (mysql-workbench-5.1.16-canvas_floater_cpp.patch)
* Tue Mar 30 2010 mhrusecky@suse.cz
- update to the version 5.2.16
  - changes:
  - http://wb.mysql.com/?p=507
* Fri Jan 29 2010 mhrusecky@suse.cz
- update to the version 5.2.15
  - changes:
  - http://wb.mysql.com/?p=482
* Thu Jan 21 2010 mhrusecky@suse.cz
- update to the version 5.2.14
  - changes:
  - http://wb.mysql.com/?p=477
* Wed Jan 20 2010 mhrusecky@suse.cz
- fixed dependencies for Fedora
* Sat Jan  9 2010 mhrusecky@suse.cz
- update to the version 5.2.11
  - changes:
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-11.html
* Sat Dec 12 2009 mhrusecky@suse.cz
- patches fixed for fuzz=0
* Wed Dec  9 2009 mhrusecky@suse.cz
- update to the version 5.2.10
  - changes:
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-9.html
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-10.html
* Mon Nov 23 2009 mhrusecky@suse.cz
- update to the version 5.2.8
  - changes:
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-7.html
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-8.html
* Tue Nov 10 2009 mhrusecky@suse.cz
- adding configuration for openSUSE
* Tue Nov 10 2009 mhrusecky@suse.cz
- fixed .desktop file
* Mon Nov  9 2009 mhrusecky@suse.cz
- forced MySQL Workbench 5.2.6 Alpha after long and painful battle
  to compile
* Mon Oct 19 2009 mhrusecky@suse.cz
- fixed path to the libraries
* Fri Oct 16 2009 mhrusecky@suse.cz
- fixed broken link to mysqlcppconn module (bnc#547164)
* Tue Jul 28 2009 mhrusecky@suse.cz
- updating spec to search for ctemplate in ctemplate instead of google
* Tue Jul 28 2009 mhrusecky@suse.cz
- updated to version 5.1.16
  - no longer alpha version
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Tue May 19 2009 mhrusecky@suse.cz
- fixed gcc 4.4 compilation errors
* Fri May 15 2009 mhrusecky@suse.cz
- updated to the version 5.1.12 (no release notes available)
  - using new version of ctemplates correctly
  - added return statements to non-void functions
* Tue Apr 21 2009 mhrusecky@suse.cz
- updated to the version 5.1.10 (no release notes available)
* Fri Feb 20 2009 mhrusecky@suse.cz
- updated to the version 5.1.7 (no release notes available)
* Tue Jan 20 2009 mhrusecky@suse.cz
- fixed file saving (not using chdir anymore)
- added big warning about alpha version
- disable console log by default when debug isn't specified
* Tue Jan 13 2009 mhrusecky@suse.cz
- fixed paths to datadir and libdir
* Mon Jan  5 2009 mhrusecky@suse.cz
- fixed url and errors reported by rpmlint
* Tue Dec 30 2008 prusnak@suse.cz
- do not use local scintilla
- repack source so it does not contain external bundled
  (and not used) sources
- do not use strict aliasing
* Sat Dec 20 2008 mhrusecky@suse.cz
- fixed some minor errors
- using system ctemplate instead of bundled one
* Thu Dec 18 2008 mhrusecky@suse.cz
- first standalone package of mysql-workbench (Version 5.1.5)
